==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>رەسىم ئۇچۇرى</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>ئاساسى ئۇچۇر</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>تەپسىلاتلار</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>ئالبومغا قوشۇش</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ئالبوم قۇرۇش</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>بارلىق رەسىملەر</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>رەسىمنى ئېچىش</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>چىقىرىش</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>ئالبومدىن چىقىرىۋېتىش</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ياقتۇرمىدىم</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ساقلاش</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>رەسىم كۆرۈش ھوقۇقىڭىز يوق</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>نامى</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>رەسىم تۈرى</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>ئۆزگەرتكەن ۋاقىت</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>چوڭ-كىچىكلىكى</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>تارتىلغان ۋاقىت</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>نۇر ئۆتۈش ھالىتى</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>نۇر ئۆتۈش پىروگراممىسى</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>نۇر ئۆتۈش ۋاقتى</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>لامپا</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>دىئافراگما چوڭ-كىچىكلىكى</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>فوكۇس ئارىلىقى</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>يورۇقلۇق سېزىش دەرىجىسى ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>ئەڭ چوڭ دىئافراگما قىممىتى</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>سىناش ھالىتى</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>ئاق تەڭپۇڭلۇق</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>لامپا تولۇقلاش</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>كامېرا تېپى</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>رەڭ بوشلۇقى</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>ئاپپارات تىپى</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>سۈرەت رازمېرى</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>بەلگە</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>قايتىش</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>ئالدىنقى</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>كىيىنكى</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 كۆرۈنسۇن</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>كۆزنەككە ماسلاشسۇن</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>تېكىستنى تونۇتۇش</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>سائەت ئىستېرىلكىسىغا قارشى يۆنىلىشتە ئايلاندۇرۇش</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>سائەت ئىستېرىلكىسى بويىچە ئايلاندۇرۇش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>تولۇق ئىكراندىن چېكىنىش</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>تولۇق ئىكران</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>بېسىش</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>تام تەسۋىر</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>نام قويۇش</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>يول باشلاش كۆزنىكىنى كۆرسەتسۇن</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>يول باشلاش كۆزنىكىنى يوشۇرسۇن</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تام رەسىمى قىلىپ تەڭشەش</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىش</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>رەسىم ئۇچۇرى</translation>
    </message>
    <message>
        <source>day</source>
        <translation>كۈن</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>جەزملەش</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>رەسىم نامىنى كىرگۈزۈڭ</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>ئالدىنقى</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ۋاقتىنچە توختىتىش</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>قويۇش</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>كىيىنكى</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>چېكىنىش</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>رەسىم ھۆججىتى بايقالمىدى</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>رەسىم ھۆججىتى بايقالمىدى</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>ھۆججەت كۆرۈش ھوقۇقىڭىز يوق</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.14.orig.tar.xz: image-editor-1.0.14/libimageviewer/translations/libimageviewer_ug.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>رەسىم ئۇچۇرى</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>ئاساسى ئۇچۇر</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>تەپسىلاتلار</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>ئالبومغا قوشۇش</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ئالبوم قۇرۇش</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>بارلىق رەسىملەر</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>رەسىمنى ئېچىش</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>چىقىرىش</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>ئالبومدىن چىقىرىۋېتىش</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ياقمىغانلىرى</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ياقتۇرغانلىرىم</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>رەسىم كۆرۈش ھوقۇقىڭىز يوق</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>نامى</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>رەسىم تۈرى</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>ئۆزگەرتكەن ۋاقىت</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>چوڭ-كىچىكلىكى</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>تارتىلغان ۋاقىت</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>نۇر ئۆتۈش ھالىتى</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>نۇر ئۆتۈش پىروگراممىسى</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>نۇر ئۆتۈش ۋاقتى</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>لامپا</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>دىئافراگما چوڭ-كىچىكلىكى</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>فوكۇس ئارىلىقى</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>يورۇقلۇق سېزىش دەرىجىسى ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>ئەڭ چوڭ دىئافراگما قىممىتى</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>سىناش ھالىتى</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>ئاق تەڭپۇڭلۇق</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>لامپا تولۇقلاش</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>كامېرا تېپى</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>رەڭ بوشلۇقى</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>ئاپپارات تىپى</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>سۈرەت رازمېرى</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>بەلگە</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>قايتىش</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>ئالدىنقى</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>كىيىنكى</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 كۆرۈنسۇن</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>كۆزنەككە ماسلاشسۇن</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>تېكىستنى تونۇتۇش</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>سائەت ئىستېرىلكىسىغا قارشى يۆنىلىشتە ئايلاندۇرۇش</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>سائەت ئىستېرىلكىسى بويىچە ئايلاندۇرۇش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>تولۇق ئىكراندىن چېكىنىش</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>تولۇق ئىكران</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>بېسىش</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>تام تەسۋىر</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>نام قويۇش</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>يول باشلاش كۆزنىكىنى كۆرسەتسۇن</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>يول باشلاش كۆزنىكىنى يوشۇرسۇن</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تام رەسىمى قىلىپ تەڭشەش</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىش</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>رەسىم ئۇچۇرى</translation>
    </message>
    <message>
        <source>day</source>
        <translation>كۈن</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>سۈرەت ئۇچۇرى</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>جەزملەش</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>رەسىم نامىنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>ئالدىنقى</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ۋاقتىنچە توختىتىش</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>قويۇش</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>كىيىنكى</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>چېكىنىش</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>رەسىم ھۆججىتى بايقالمىدى</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>رەسىم ھۆججىتى بايقالمىدى</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>ھۆججەت كۆرۈش ھوقۇقىڭىز يوق</translation>
    </message>
</context>
</TS>
